==> haskell-nettle-0.2.0-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-54MsI4KSmNQFBnQ0PgRfAi
key: nettle-0.2.0-54MsI4KSmNQFBnQ0PgRfAi
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: e4a05e2a165ca92c41919d1bebee3e1f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-54MsI4KSmNQFBnQ0PgRfAi
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-Gaasy8ZWU3y7kxB46txgJY
    securemem-0.1.9-E3A92GFzWR8Jl7bHNv7cPG
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.2.0-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-9Nz7PdSkd9u6Z4TO5dKeE2
key: nettle-0.2.0-9Nz7PdSkd9u6Z4TO5dKeE2
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: 15394fa3c3c0052f194a56a8c999accf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-9Nz7PdSkd9u6Z4TO5dKeE2
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-6q0yWWdZrHZ6FgG0msGljn
    securemem-0.1.9-BEpNQw6mkLfDLYCyNkxHXF
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
